# arpes.plotting.band\_tool module

**class arpes.plotting.band\_tool.BandTool(**kwargs)\*\*

> Bases: `arpes.plotting.interactive_utils.SaveableTool`,
> [arpes.plotting.interactive\_utils.CursorTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.CursorTool)
> 
> Two dimensional fitting band tool
> 
> `auto_rebin = False`
> 
> `auto_zero_nans = False`
> 
> **deserialize(json\_data)**
> 
> **serialize()**
> 
> **tool\_handler(doc)**
